import { useContext, useMemo } from 'react';
import PdeContext from '../contexts/PdeContext';
/**
 * Hook to use a experiment
 * @param {string} experimentName
 * @param {object} attributes
 * @return {{variation: string}}
 */

export default function useExperiment(experimentName, attributes) {
  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[useExperiment] pde is required to work');
  var variation = useMemo(function () {
    return pde.activateExperiment({
      name: experimentName,
      attributes: attributes
    });
  }, [experimentName, pde, attributes]);
  return {
    variation: variation
  };
}